@@ -13,10 +13,8 @@ function(p,M=10^4)
 
   cat(paste("Number of Hops N:  ",length(p)),"\n")
   cat(paste("Probabilities:     ", paste(p, collapse=", ")),"\n")
+  cat(paste("Simulations M:     ", paste(M, collapse=", ")),"\n")
   cat("   ","\n")
-  cat("#######","\n")
-  cat("Results","\n")
-  cat("#######","\n")
   out = MC(p,M)
   cat("   ","\n")
   print(out)
